@@ -1,10 +1,13 @@
 import collections
 import re
 import sys
+from typing import Tuple
 
-from .plugin import PostgresCredentials, run_pg  # noqa
+from .fixtures import PG, pg, pg_11, pg_12, pg_13, pg_14, run_pg  # noqa
 
-__version__ = "0.0.7"
+__all__: Tuple[str, ...] = ("PG", "run_pg", "pg", "pg_11", "pg_12", "pg_13", "pg_14")
+
+__version__ = "0.0.8"
 
 version = f"{__version__}, Python {sys.version}"
 
